==> 0.0.1.tar.gz: lib/network/config.dart <==
class Config {
  static Env environment = Env.development;
  
  static bool enableForceLog = false;
  static bool isTesting = false;

  static String _path = '/user/';

  Map<String, String> get headers => {
    "Content-Type": "application/json",
    "Accept": "application/json",
    "Authorization": "Bearer $bearer",
  };


  static String appName = 'Hris Mobile';
  static String _developmentDomain = 'api-hris-gjr.corea.tech';
  static String _stagingDomain = 'dtech';
  static String _productionDomain = 'trim';

  static String _developmentAuthId = 'a678803588713b45ae8baf50adefb813';
  static String _stagingAuthId = 'a67880350adefb813';
  static String _productionAuthId = 'd8ef0669d24781b7071b0';

  static String bearer = '13a15d6d82a73178b92cae63b468a4f16d12c9733e2095529fa86e6104d8c727';

  static bool get isDevelopment => environment == Env.development;
  static bool get isStaging => environment == Env.staging;
  static bool get isProduction => environment == Env.production;

  static String get scheme => isProduction ? 'https' : 'https';
  static String get baseUrl => scheme + '://' + domain + "/api/";
  static String get baseUrlNoPath => scheme + '://' + domain;
  static String get langPackUrl => scheme + '://' + domain + '/lang/pack/';

  Loading isLoading = Loading.hide;

  Future<bool> checkError(int code) async {

    bool isFalse = true;

    if (code == 2000){

      isFalse = false;
    }

    if (code == 111){
      isFalse = false;
    }

    return isFalse;
  }

  static String get domain {
    String domain = '';
    switch(environment){
      case Env.development:
        domain = _developmentDomain;
        break;
      case Env.staging:
        domain = _stagingDomain;
        break;
      case Env.production:
        domain = _productionDomain;
        break;
    }
    return domain;
  }

  static String get authId{
    String authId = '';
    switch(environment){
      case Env.development:
        authId = _developmentAuthId;
        break;
      case Env.staging:
        authId = _stagingAuthId;
        break;
      case Env.production:
        authId = _productionAuthId;
        break;
    }
    return authId;
  }

}

enum Loading {
  hide, show
}

enum Env{
  development, staging, production
}

==> 0.0.2.tar.gz: lib/network/config.dart <==
import 'package:flutter/cupertino.dart';

class Config {
  static Env environment;
  
  static bool enableForceLog = false;
  static bool isTesting = false;

  static String _path = '/user/';

  BuildContext context;

  Config({this.context});

  Map<String, String> get headers => {
    "Content-Type": "application/json",
    "Accept": "application/json",
    "Authorization": "Bearer $bearer",
  };

  static String appName;
  static String developmentDomain;
  static String stagingDomain;
  static String productionDomain;

  static String developmentAuthId;
  static String stagingAuthId;
  static String productionAuthId;

  static Color colorMain;

  static String bearer;

  static bool get isDevelopment => environment == Env.development;
  static bool get isStaging => environment == Env.staging;
  static bool get isProduction => environment == Env.production;

  static String get scheme => isProduction ? 'https' : 'https';
  static String get baseUrl => scheme + '://' + domain + "/api/";
  static String get baseUrlNoPath => scheme + '://' + domain;
  static String get langPackUrl => scheme + '://' + domain + '/lang/pack/';

  static Widget alertFailed;
  void alertCustom;
  String messageError;

  Loading isLoading = Loading.hide;

  Future<bool> checkError(int code) async {

    bool isFalse = true;

    if (code == 2000){

      isFalse = false;
    }

    if (code == 111){
      isFalse = false;
    }

    return isFalse;
  }

  static String get domain {
    String domain = '';
    switch(environment){
      case Env.development:
        domain = developmentDomain;
        break;
      case Env.staging:
        domain = stagingDomain;
        break;
      case Env.production:
        domain = productionDomain;
        break;
    }
    return domain;
  }

  static String get authId{
    String authId = '';
    switch(environment){
      case Env.development:
        authId = developmentAuthId;
        break;
      case Env.staging:
        authId = stagingAuthId;
        break;
      case Env.production:
        authId = productionAuthId;
        break;
    }
    return authId;
  }

}

enum Loading {
  hide, show
}

enum Env{
  development, staging, production
}
